@@ -38,7 +38,7 @@ class Upload(object):
 
     def __iter__(self):
         yield self.filename
-        if self.content:
+        if self.content is not None:
             yield self.content
             yield self.content_type
         # TODO: do we handle the case when we need to get
@@ -293,6 +293,10 @@ class Text(Field):
     """Field representing ``<input type="text">``"""
 
 
+class Email(Field):
+    """Field representing ``<input type="email">``"""
+
+
 class File(Field):
     """Field representing ``<input type="file">``"""
 
@@ -328,8 +332,8 @@ class Submit(Field):
     value = property(value__get, value__set)
 
     def value_if_submitted(self):
-        # TODO: does this ever get set?
-        return self._value
+        # parsed value of the empty string
+        return self._value or ''
 
 
 Field.classes['submit'] = Submit
@@ -348,6 +352,8 @@ Field.classes['file'] = File
 
 Field.classes['text'] = Text
 
+Field.classes['email'] = Email
+
 Field.classes['password'] = Text
 
 Field.classes['checkbox'] = Checkbox
